multiples_sum: multiples_sum get the sum of the multiples of the numbers...

Description Usage Arguments Value

View source: R/helpers.R

Description

multiples_sum get the sum of the multiples of the numbers specified less than the max value specified

Usage

1
multiples_sum(numbers = c(3, 5), max_value = 1000)

Arguments

numbers

the numbers whose multiples to include in the sum

max_value

the largest number to consider

Value

the sum


mrkaye97/euleR documentation built on July 5, 2021, 1:44 p.m.