problem_1: Problem 1

Description Usage Value

View source: R/solutions.R

Description

If we list all the natural numbers below 10 that are multiples of 3 or 5, we get 3, 5, 6 and 9. The sum of these multiples is 23. Find the sum of all the multiples of 3 or 5 below 1000.

Usage

1

Value

the sum


mrkaye97/euleR documentation built on July 5, 2021, 1:44 p.m.