problem_2: Problem 2

Description Usage Value

View source: R/solutions.R

Description

Each new term in the Fibonacci sequence is generated by adding the previous two terms. By starting with 1 and 2, the first 10 terms will be: 1, 2, 3, 5, 8, 13, 21, 34, 55, 89, ... By considering the terms in the Fibonacci sequence whose values do not exceed four million, find the sum of the even-valued terms.

Usage

1

Value

the sum


mrkaye97/euleR documentation built on July 5, 2021, 1:44 p.m.