problem_35: Problem 35

Description Usage Arguments Value

View source: R/solutions.R

Description

The number, 197, is called a circular prime because all rotations of the digits: 197, 971, and 719, are themselves prime. There are thirteen such primes below 100: 2, 3, 5, 7, 11, 13, 17, 31, 37, 71, 73, 79, and 97. How many circular primes are there below one million?

Usage

1
problem_35(workers = 8)

Arguments

workers

the number of workers to use for parallel computing

Value

the number of circular primes


mrkaye97/euleR documentation built on July 5, 2021, 1:44 p.m.