triangle_greater_than_max: triangle_greater_than_max

Description Usage Arguments Value

View source: R/helpers.R

Description

test if a triangle number is greater than some specified maximum value

Usage

1

Arguments

n

the number to test (i.e. the 10th triangle number)

max_num

the max to test against

Value

a boolean (true if the nth triangle number is bigger than the max to test)


mrkaye97/euleR documentation built on July 5, 2021, 1:44 p.m.