Description Usage Arguments Value
multiples_sum get the sum of the multiples of the numbers specified less than the max value specified
1 | multiples_sum(numbers = c(3, 5), max_value = 1000)
|
numbers |
the numbers whose multiples to include in the sum |
max_value |
the largest number to consider |
the sum
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.