Description Usage Arguments Value
test if a triangle number is greater than some specified maximum value
1 | triangle_greater_than_max(n, max_num)
|
n |
the number to test (i.e. the 10th triangle number) |
max_num |
the max to test against |
a boolean (true if the nth triangle number is bigger than the max to test)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.